*

#include <HCSR04.h>          

// Define the hardware connections:
const int pin_buzzer = 3;     //digital pin where the buzzer is connceted to
const int pin_Echo = 10;       // digital pin for HC-SR04 echo connector
const int pin_Trigger = 8;    // digital pin for HC-SR04 Trigger connector

//Define LED pins
const int red_led = 11;    //digital pin for red led
//const int yellow_led = 8;  //digital pin for yellow led
const int green_led = 12;   //digital pin for green led

// Define the signalling
const int tone_repeat = 1;    // How often a tone / smile will be repeated

const int tone_low = 800;     // Frequency for tone if emergency level is low
const int time_low = 500;     // Tone duration if emergency level is low
const int dist_low = 120;     // distance level for low emergency level
 
const int tone_medium = 1600; // Frequency for tone if emergency level is medium
const int time_medium = 350;  // Tone duration if emergency level is medium
const int dist_medium = 80;   // distance level for medium emergency level 

const int tone_high = 2400;   // Frequency for tone if emergency level is high
const int time_high = 200;    // Tone duration if emergency level is high
const int dist_high = 50;     // distance level for high emergency level

// to store the current distance:
float distance;               // distance read from ultrasonic sensor

//create an instance to control the sensor:
UltraSonicDistanceSensor distanceSensor(pin_Trigger, pin_Echo);  // Initialize sensor 

setup () {
  Serial.begin(9600);     // Enabled for debzg

  // set all LED pins as output
  pinMode(red_led, OUTPUT);
  pinMode(green_led, OUTPUT);
 
  Start(200);                // Call start eequence
}


void Start(int startspeed) {
  digitalWrite(green_led,HIGH);
  delay(startspeed);
  
  digitalWrite(red_led,HIGH);
  delay(startspeed);
  

  delay(500);

  digitalWrite(green_led,LOW);
  delay(startspeed);

  digitalWrite(red_led,LOW);
  delay(startspeed);

}

/*
 * Set all green LEDs on
 */
void greenSmile() {
  
  digitalWrite(green_led,HIGH);

  

}


/*
 * Set all red LEDs on
 */
void redSmile() {
  
   digitalWrite(red_led,HIGH);
 

}


/*
 * Set all LEDs off
 */
void offSmile() {
    digitalWrite(green_led,LOW);
//    digitalWrite(yellow_led,LOW);
    digitalWrite(red_led,LOW);
}

/*
 * Signal to short distance
 * ========================
 *
 * Params:
 * -------
 *  level: "loudness" of signaling -> 0 (off), 1 (low),2 (medium) or 3 (high)
 * 
 */

void emergency(int level) {
  switch (level) {
    case 0:             // off
      greenSmile();
      
      noTone(pin_buzzer);
      break;
    case 1:             // low
      for (int i = 1; i <= tone_repeat; i++) {
        tone (pin_buzzer, tone_low, time_low);
        redSmile();
        delay (time_low);
        offSmile();
        delay (time_low);
      }
      break;
    case 2:             // medium
      for (int i = 1; i <= tone_repeat; i++) {
        tone (pin_buzzer, tone_medium, time_medium);
        redSmile();
        delay (time_medium);
        offSmile();
        delay (time_medium);
      }
      break;
    case 3:             // high
      for (int i = 1; i <= tone_repeat; i++) {
        tone (pin_buzzer, tone_high, time_high);
        redSmile();
        delay (time_high);
        offSmile();
        delay (time_high);
      }   
      break;
    default:  // default = off
      noTone(pin_buzzer);
      greenSmile();
      //redSmile();
      delay (time_low);
      break;
  }
}



/*
 * The main programm loop:
 * 
 * - read current distance
 * - compare with distance intervals defined above
 * - call signalling (emergency) routine to set smiling and beeping
 */
void loop () {
    distance = distanceSensor.measureDistanceCm();  // read current distance
    Serial.println(distance);                       // output for debug

    // check interval:
    if (distance <= dist_high && distance >=0)
    {
      emergency(3);
    }
    else if (distance <= dist_medium && distance >=0)
    {
      emergency(2);
    }
    else if (distance <= dist_low && distance >=0)
    {
      emergency(1);
    }
    else if (distance > dist_low && distance >=0 )
    {
      emergency(0);
    }
    delay(100);   // wait a bit :-)
 
}
